| Title: | Access Data Dependencies Installed Through 'Biobricks.ai' |
|---|---|
| Description: | Provides an integrated data management solution for assets installed via the 'Biobricks.ai' platform. Streamlines the process of loading and interacting with diverse datasets in a consistent manner. A list of bricks is available at <https://status.biobricks.ai>. Documentation for 'Biobricks.ai' is available at <https://docs.biobricks.ai>. |
| Authors: | Thomas Luechtefeld [aut, cre] |
| Maintainer: | Thomas Luechtefeld <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.2 |
| Built: | 2026-05-27 10:38:44 UTC |
| Source: | https://github.com/cran/biobricks |
Return a list of tables for a brick
bbassets(brick)bbassets(brick)
brick |
the name of the brick to load |
A named list where each element is a character string representing the full path to a specific asset file. The keys of the list correspond to the types of asset files available.