Welcome to ClientVPS Mirrors

Help for package biobricks
Type: Package
Title: Access Data Dependencies Installed Through 'Biobricks.ai'
Version: 0.2.2
Description: Provides an integrated data management solution for assets installed via the 'Biobricks.ai' platform. Streamlines the process of loading and interacting with diverse datasets in a consistent manner. A list of bricks is available at https://status.biobricks.ai. Documentation for 'Biobricks.ai' is available at https://docs.biobricks.ai.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: testthat, covr
Config/testthat/edition: 3
Maintainer: Thomas Luechtefeld <tom@insilica.co>
NeedsCompilation: no
Packaged: 2023-10-31 18:19:43 UTC; tom
Author: Thomas Luechtefeld [aut, cre]
Repository: CRAN
Date/Publication: 2023-11-01 13:10:05 UTC

Return a list of tables for a brick

Description

Return a list of tables for a brick

Usage

bbassets(brick)

Arguments

brick

the name of the brick to load

Value

A named list where each element is a character string representing the full path to a specific asset file. The keys of the list correspond to the types of asset files available.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.